@@ -3,7 +3,6 @@ from bricked.server.models.user_model import UserModel
 
 
 class AuthController(Controller):
-
     async def show(self, user: UserModel):
         print("AuthController@show: user: '{}'".format(user))  # DEBUG
-        return self.text('home page')
+        return self.text("home page")
